<?php

namespace Drupal\Tests\twig_tools\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests Twig Tools sanitize filters.
 *
 * @group twig_tools
 */
class TwigSanitizeTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['twig_tools'];

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigSanitize::cleanClassArray
   */
  public function testCleanClassArray() {

    $template = "{{ clean_class_array_test|clean_class_array|safe_join(' ') }}";
    $expected_output = 'abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-0123456789 ¡¢£¤¥ css__identifier__with__double__underscores invalid---identifier block__element--modifier';

    $context = [
      'clean_class_array_test' => [
        'abcdefghijklmnopqrstuvwxyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789',
        '¡¢£¤¥',
        'css__identifier__with__double__underscores',
        'invalid !"#$%&\'()*+,./:;<=>?@[\\]^`{|}~ identifier',
        'block__element--modifier',
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigSanitize::arrayUnique
   */
  public function testArrayUnique() {

    $template = "{{ array_unique_test|array_unique|safe_join(', ') }}";
    $expected_output = '0, 1, 2, 3, , Unique, Not Unique';

    $context = [
      'array_unique_test' => [
        '0',
        '1',
        '2',
        '3',
        '0',
        '1',
        NULL,
        FALSE,
        TRUE,
        'Unique',
        'Not Unique',
        'Not Unique',
        0,
        1,
        2,
        0.0,
        1.0,
        2.0,
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);
  }

  /**
   * @covers Drupal\twig_tools\TwigExtension\TwigSanitize::removeEmpty
   */
  public function testRemoveEmpty() {

    $template = "{{ remove_empty_test|remove_empty|safe_join(', ') }}";
    $expected_output = '1, 2, 3, 1, 1, 2, 1, 2, 1, Unique';

    $context = [
      'remove_empty_test' => [
        '0',
        '1',
        '2',
        '3',
        '0',
        '1',
        0,
        1,
        2,
        0.0,
        1.0,
        2.0,
        FALSE,
        TRUE,
        NULL,
        'Unique',
        [],
      ],
    ];

    /** @var \Drupal\Core\Template\TwigEnvironment $environment */
    $environment = \Drupal::service('twig');
    $output = (string) $environment->renderInline($template, $context);

    $this->assertSame($expected_output, $output);

  }

}
